find_unsynchronized_mutation

Function find_unsynchronized_mutation 

fn find_unsynchronized_mutation<'tcx>(
    tcx: TyCtxt<'tcx>,
    ty: Ty<'tcx>,
    impl_def_id: DefId,
    is_sync: bool,
) -> Contains
Find an interior-mutability / raw-pointer field that is not guarded by a synchronization primitive. A raw pointer may also appear as a pattern type (pattern_type!(*const T is ..)), so recurse into TyKind::Pat.