has_atomic_ptr_updates

Function has_atomic_ptr_updates 

fn has_atomic_ptr_updates<'tcx>(tcx: TyCtxt<'tcx>, ty: Ty<'tcx>) -> bool
Whether any inherent method of ty performs an atomic update through an atomic intrinsic or an Atomic* method (fetch_add/store/…), e.g. an Arc-style fetch_add on a reference count reached via a raw pointer.